//Handles DELETE requests for specific items
import { NextRequest, NextResponse } from 'next/server';
import { deleteItemByUrl } from '@/lib/database';

// DELETE /api/urls/[encodedUrl]/items/[itemId] - Delete a specific item
export async function DELETE(
  request: NextRequest,
  { params }: { params: { encodedUrl: string; itemId: string } }
) {
  const url = decodeURIComponent(params.encodedUrl);
  const itemId = params.itemId;
  
  console.log('[API] Deleting item', itemId, 'from URL', url);

  try {
    if (!itemId) {
      return NextResponse.json(
        { error: 'Item ID is required' },
        { status: 400 }
      );
    }

    await deleteItemByUrl(url, itemId);
    
    console.log('[API] Successfully deleted item:', itemId);
    
    return NextResponse.json(
      { message: 'Item deleted', itemId: itemId },
      { status: 200 }
    );
  } catch (error) {
    console.log('[API] Delete error:', error);
    
    return NextResponse.json(
      { 
        error: 'Failed to delete item',
        details: error instanceof Error ? error.message : 'Unknown error',
        itemId: itemId,
        url: url
      },
      { status: 500 }
    );
  }
}